#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_BITFLOATING_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_BITFLOATING_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/bitfloating.hpp>

#endif
